Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3481)

Unified Diff: chrome/browser/ui/webui/chrome_web_ui_controller_factory.cc

Issue 10534098: TabContentsWrapper -> TabContents, part 51. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/chrome_web_ui_controller_factory.cc
diff --git a/chrome/browser/ui/webui/chrome_web_ui_controller_factory.cc b/chrome/browser/ui/webui/chrome_web_ui_controller_factory.cc
index f61f82bc09ff2d0ca0200eec45fe8f17a20420b6..6b8e9414074d46ff3524f6d762bbd697345f7ce8 100644
--- a/chrome/browser/ui/webui/chrome_web_ui_controller_factory.cc
+++ b/chrome/browser/ui/webui/chrome_web_ui_controller_factory.cc
@@ -14,7 +14,7 @@
#include "chrome/browser/printing/print_preview_tab_controller.h"
#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/profiles/profile_manager.h"
-#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
+#include "chrome/browser/ui/tab_contents/tab_contents.h"
#include "chrome/browser/ui/webui/about_ui.h"
#include "chrome/browser/ui/webui/bookmarks_ui.h"
#include "chrome/browser/ui/webui/crashes_ui.h"
@@ -116,7 +116,7 @@ WebUIController* NewWebUI<AboutUI>(WebUI* web_ui, const GURL& url) {
}
// Only create ExtensionWebUI for URLs that are allowed extension bindings,
// hosted by actual tabs. If tab_contents has no wrapper, it likely refers
// to another container type, like an extension background page. If there is
// no WebUI (it's not accessible when calling GetWebUIType and related
// functions) then we conservatively assume that we need a WebUI.
@@ -125,9 +125,7 @@ bool NeedsExtensionWebUI(WebUI* web_ui,
const GURL& url) {
ExtensionService* service = profile ? profile->GetExtensionService() : NULL;
return service && service->ExtensionBindingsAllowed(url) &&
- (!web_ui ||
- TabContentsWrapper::GetCurrentWrapperForContents(
- web_ui->GetWebContents()));
+ (!web_ui || TabContents::FromWebContents(web_ui->GetWebContents()));
}
// Returns a function that can be used to create the right type of WebUI for a
« no previous file with comments | « chrome/browser/ui/webui/certificate_viewer_webui.cc ('k') | chrome/browser/ui/webui/constrained_web_dialog_delegate_base.h » ('j') | no next file with comments »
@@ -116,7 +116,7 @@ WebUIController* NewWebUI<AboutUI>(WebUI* web_ui, const GURL& url) {
}
// Only create ExtensionWebUI for URLs that are allowed extension bindings,
-// hosted by actual tabs. If tab_contents has no wrapper, it likely refers
+// hosted by actual tabs. If there is no TabContents, it likely refers
// to another container type, like an extension background page. If there is
// no WebUI (it's not accessible when calling GetWebUIType and related

Powered by Google App Engine
This is Rietveld 408576698